==> kubernetes-model-1.0.54-sources.jar: io/fabric8/openshift/api/model/CustomDeploymentStrategyParamsBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class CustomDeploymentStrategyParamsBuilder extends CustomDeploymentStrategyParamsFluentImpl<CustomDeploymentStrategyParamsBuilder> implements VisitableBuilder<CustomDeploymentStrategyParams,CustomDeploymentStrategyParamsBuilder>{

    CustomDeploymentStrategyParamsFluent<?> fluent;
    Boolean validationEnabled;

    public CustomDeploymentStrategyParamsBuilder(){
            this(true);
    }
    public CustomDeploymentStrategyParamsBuilder(Boolean validationEnabled){
            this(new CustomDeploymentStrategyParams(), validationEnabled);
    }
    public CustomDeploymentStrategyParamsBuilder(CustomDeploymentStrategyParamsFluent<?> fluent){
            this(fluent, true);
    }
    public CustomDeploymentStrategyParamsBuilder(CustomDeploymentStrategyParamsFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new CustomDeploymentStrategyParams(), validationEnabled);
    }
    public CustomDeploymentStrategyParamsBuilder(CustomDeploymentStrategyParamsFluent<?> fluent,CustomDeploymentStrategyParams instance){
            this(fluent, instance, true);
    }
    public CustomDeploymentStrategyParamsBuilder(CustomDeploymentStrategyParamsFluent<?> fluent,CustomDeploymentStrategyParams instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withCommand(instance.getCommand()); 
            fluent.withEnvironment(instance.getEnvironment()); 
            fluent.withImage(instance.getImage()); 
            this.validationEnabled = validationEnabled; 
    }
    public CustomDeploymentStrategyParamsBuilder(CustomDeploymentStrategyParams instance){
            this(instance,true);
    }
    public CustomDeploymentStrategyParamsBuilder(CustomDeploymentStrategyParams instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withCommand(instance.getCommand()); 
            this.withEnvironment(instance.getEnvironment()); 
            this.withImage(instance.getImage()); 
            this.validationEnabled = validationEnabled; 
    }

    public CustomDeploymentStrategyParams build(){
            CustomDeploymentStrategyParams buildable = new CustomDeploymentStrategyParams(fluent.getCommand(),fluent.getEnvironment(),fluent.getImage());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            CustomDeploymentStrategyParamsBuilder that = (CustomDeploymentStrategyParamsBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.60-sources.jar: io/fabric8/openshift/api/model/CustomDeploymentStrategyParamsBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class CustomDeploymentStrategyParamsBuilder extends CustomDeploymentStrategyParamsFluentImpl<CustomDeploymentStrategyParamsBuilder> implements VisitableBuilder<CustomDeploymentStrategyParams,CustomDeploymentStrategyParamsBuilder>{

    CustomDeploymentStrategyParamsFluent<?> fluent;
    Boolean validationEnabled;

    public CustomDeploymentStrategyParamsBuilder(){
            this(true);
    }
    public CustomDeploymentStrategyParamsBuilder(Boolean validationEnabled){
            this(new CustomDeploymentStrategyParams(), validationEnabled);
    }
    public CustomDeploymentStrategyParamsBuilder(CustomDeploymentStrategyParamsFluent<?> fluent){
            this(fluent, true);
    }
    public CustomDeploymentStrategyParamsBuilder(CustomDeploymentStrategyParamsFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new CustomDeploymentStrategyParams(), validationEnabled);
    }
    public CustomDeploymentStrategyParamsBuilder(CustomDeploymentStrategyParamsFluent<?> fluent,CustomDeploymentStrategyParams instance){
            this(fluent, instance, true);
    }
    public CustomDeploymentStrategyParamsBuilder(CustomDeploymentStrategyParamsFluent<?> fluent,CustomDeploymentStrategyParams instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withCommand(instance.getCommand()); 
            fluent.withEnvironment(instance.getEnvironment()); 
            fluent.withImage(instance.getImage()); 
            this.validationEnabled = validationEnabled; 
    }
    public CustomDeploymentStrategyParamsBuilder(CustomDeploymentStrategyParams instance){
            this(instance,true);
    }
    public CustomDeploymentStrategyParamsBuilder(CustomDeploymentStrategyParams instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withCommand(instance.getCommand()); 
            this.withEnvironment(instance.getEnvironment()); 
            this.withImage(instance.getImage()); 
            this.validationEnabled = validationEnabled; 
    }

    public CustomDeploymentStrategyParams build(){
            CustomDeploymentStrategyParams buildable = new CustomDeploymentStrategyParams(fluent.getCommand(),fluent.getEnvironment(),fluent.getImage());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            CustomDeploymentStrategyParamsBuilder that = (CustomDeploymentStrategyParamsBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
